==> igniteui-react-charts-16.6.4.tgz: package/ES5/OnBalanceVolumeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { OnBalanceVolumeIndicatorStrategy } from "./OnBalanceVolumeIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
var OnBalanceVolumeIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(OnBalanceVolumeIndicator, _super);
    function OnBalanceVolumeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicator.prototype.get_p3 = function () {
        return new OnBalanceVolumeIndicatorStrategy();
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "p3", {
        get: function () {
            return this.get_p3();
        },
        enumerable: true,
        configurable: true
    });
    OnBalanceVolumeIndicator.prototype.get_qg = function () {
        return OnBalanceVolumeIndicator.$;
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "qg", {
        get: function () {
            return this.get_qg();
        },
        enumerable: true,
        configurable: true
    });
    OnBalanceVolumeIndicator.$t = markType(OnBalanceVolumeIndicator, 'OnBalanceVolumeIndicator', StrategyBasedIndicator.$);
    return OnBalanceVolumeIndicator;
}(StrategyBasedIndicator));
export { OnBalanceVolumeIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/OnBalanceVolumeIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { OnBalanceVolumeIndicatorStrategy } from "./OnBalanceVolumeIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var OnBalanceVolumeIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(OnBalanceVolumeIndicator, _super);
    function OnBalanceVolumeIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OnBalanceVolumeIndicator.prototype.get_p5 = function () {
        return new OnBalanceVolumeIndicatorStrategy();
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    OnBalanceVolumeIndicator.prototype.get_qi = function () {
        return OnBalanceVolumeIndicator.$;
    };
    Object.defineProperty(OnBalanceVolumeIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    OnBalanceVolumeIndicator.$t = markType(OnBalanceVolumeIndicator, 'OnBalanceVolumeIndicator', StrategyBasedIndicator.$);
    return OnBalanceVolumeIndicator;
}(StrategyBasedIndicator));
export { OnBalanceVolumeIndicator };
